summaryrefslogtreecommitdiffstats
path: root/scene/3d/xr_body_modifier_3d.cpp
diff options
context:
space:
mode:
authorMalcolm Nixon <Malcolm.nixon@gmail.com>2024-03-02 22:17:29 -0500
committerMalcolm Nixon <Malcolm.nixon@gmail.com>2024-03-02 22:17:29 -0500
commit8fcf385ac59e42c1d8163c534a78eb34dc100344 (patch)
tree6323d42a0ace762738f96ab88d2edfbd008d757a /scene/3d/xr_body_modifier_3d.cpp
parentf2045ba822bff7d34964901393581a3117c394a9 (diff)
downloadredot-engine-8fcf385ac59e42c1d8163c534a78eb34dc100344.tar.gz
Allow the hips joint to be positioned even if the bone update mode is set to "Rotation Only".
Diffstat (limited to 'scene/3d/xr_body_modifier_3d.cpp')
-rw-r--r--scene/3d/xr_body_modifier_3d.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/scene/3d/xr_body_modifier_3d.cpp b/scene/3d/xr_body_modifier_3d.cpp
index 3414ce13ae..82fcc941ed 100644
--- a/scene/3d/xr_body_modifier_3d.cpp
+++ b/scene/3d/xr_body_modifier_3d.cpp
@@ -353,8 +353,9 @@ void XRBodyModifier3D::_update_skeleton() {
const int parent_joint = joints[joint].parent_joint;
const Transform3D relative_transform = inv_transforms[parent_joint] * transforms[joint];
- // Update the bone position if enabled by update mode.
- if (bone_update == BONE_UPDATE_FULL) {
+ // Update the bone position if enabled by update mode, or if the joint is the hips to allow
+ // for climbing or crouching.
+ if (bone_update == BONE_UPDATE_FULL || joint == XRBodyTracker::JOINT_HIPS) {
skeleton->set_bone_pose_position(joints[joint].bone, relative_transform.origin);
}